function [Labels] = CompleteLinkage(Dists)
%
% [Labels] = CompleteLinkage(Dists)
%
% Complete linkage clustering
%
%
% INPUT:
% - Dists   : Distance matrix.
%
% OUTPUT:
% - Labels  : Labeling of the clusters.
%             Each row represents an object, while each column contains
%             the labeling list after each iteration.
%
%
%
%  Author:   Analytical Chemistry
%            Institute for Molecules and Materials
%            Radboud University Nijmegen
%            Nijmegen, The Netherlands
%  Created:  November 24, 2006
%  Updated:  
%

[m,m1] = size(Dists);
Dists = Dists + diag(Inf*ones(1,m));

Labels = [1:m]';
iter_nr = 0;
while min(min(Dists))~=Inf
    iter_nr = iter_nr + 1;
    
    % Determine two objects with minimum distance
    [min_1, pos_1] = min(Dists);
    [min_2, pos_2] = min(min_1);
    pos_1 = pos_1(pos_2);
    
    % Make sure only the right part of the distance matrix is considered
	if pos_1 > pos_2
        pos_3 = pos_2;
        pos_2 = pos_1;
        pos_1 = pos_3;
    end
    
    % Replace the distances for the two objects by the minimum distances
    Dists_max = max(Dists(pos_1,:), Dists(pos_2,:));
    Dists(pos_2,:) = Dists_max;
    Dists(:,pos_2) = Dists_max';
    Dists(pos_2,pos_2) = Inf;
        
    % Replace the largest distances for the two objects by Inf
    Dists(pos_1,:) = Inf;
    Dists(:,pos_1) = Inf;
    
    % Generate a list which contains the cluster-label of each object
    Labels(:,iter_nr+1) = Labels(:,iter_nr);
    loc_1 = find(Labels(:,iter_nr+1)==Labels(pos_1,iter_nr+1));
    loc_2 = find(Labels(:,iter_nr+1)==Labels(pos_2,iter_nr+1));
    Labels([loc_1;loc_2],iter_nr+1) = Labels(pos_1,iter_nr+1);
    
    % Make sure the cluster-labels are successive
    [temp1, temp2, newlist] = unique(Labels(:,iter_nr+1));
    Labels(:,iter_nr+1) = newlist;
end


